@@ -180,20 +180,23 @@ class ActionPlanItemForm(formapi.Form):
     def valid_start_day(self):
         day = self.data["planning_start_day"]
         if day is None:
-            return
+            if not self.data["planning_start_year"]:
+                return
+            else:
+                yield _(u"Please provide the day of the month")
         if not 1 <= day <= 31:
             yield _(u"Invalid day of month")
 
         try:
-            (__, maxday) = calendar.monthrange(self.data["planning_start_year"],
-                                            self.data["planning_start_month"])
-            if day>maxday:
+            (__, maxday) = calendar.monthrange(
+                    self.data["planning_start_year"],
+                    self.data["planning_start_month"])
+            if day > maxday:
                 yield _(u"Invalid day of month")
-        except TypeError:
+        except (ValueError, TypeError):
             # Invalid year most likely
             pass
 
-
     @formapi.validator("planning_start_year")
     def valid_start_year(self):
         year = self.data["planning_start_year"]
@@ -202,21 +205,26 @@ class ActionPlanItemForm(formapi.Form):
 
         if year < 1900:
             yield _(u"Please enter a year after 1900")
+        elif year > 2100:
+            yield _(u"Please enter a year before 2100")
 
     @formapi.validator("planning_end_day")
     def valid_end_day(self):
         day = self.data["planning_end_day"]
         if day is None:
-            return
+            if not self.data["planning_end_year"]:
+                return
+            else:
+                yield _(u"Please provide the day of the month")
         if not 1 <= day <= 31:
             yield _(u"Invalid day of month")
 
         try:
-            (__, maxday)=calendar.monthrange(self.data["planning_end_year"],
+            (__, maxday) = calendar.monthrange(self.data["planning_end_year"],
                                             self.data["planning_end_month"])
-            if day>maxday:
+            if day > maxday:
                 yield _(u"Invalid day of month")
-        except TypeError:
+        except (ValueError, TypeError):
             # Invalid year most likely
             pass
 
@@ -228,6 +236,8 @@ class ActionPlanItemForm(formapi.Form):
 
         if year < 1900:
             yield _(u"Please enter a year after 1900")
+        elif year > 2100:
+            yield _(u"Please enter a year before 2100")
 
 
 
@@ -266,6 +276,8 @@ class ActionPlanView(grok.View):
             return None
         return datetime.date(year, month, day)
 
+    def get_action_plans(self):
+        return sorted(self.context.action_plans, key=lambda k: k.id)
 
     def update(self):
         if redirectOnSurveyUpdate(self.request):
@@ -338,13 +350,13 @@ class ActionPlanView(grok.View):
                         self.request.response.redirect(url)
                         return
 
-                url=QuestionURL(self.request.survey, next, phase="actionplan")
+                url = QuestionURL(self.request.survey, next, phase="actionplan")
                 self.request.response.redirect(url)
                 return
         else:
             if len(context.action_plans) == 0:
                 context.action_plans.append(model.ActionPlan())
-            self.data=context
+            self.data = context
 
         self.risk = risk = self.request.survey.restrictedTraverse(
                                         context.zodb_path.split("/"))
